@@ -1295,9 +1295,12 @@ TEST(PersistentStringCacheImpl, exceptions)
             }
             catch (system_error const& e)
             {
-                EXPECT_EQ("PersistentStringCache: check_version(): bad version: \"nan\" (cache_path: " + TEST_DB +
-                          "): Unknown error 666",
-                          e.what());
+                string msg = e.what();
+                EXPECT_TRUE(boost::starts_with(
+                    msg,
+                    "PersistentStringCache: check_version(): "
+                    "bad version: \"nan\" (cache_path: " +
+                    TEST_DB + "): ")) << msg;
             }
         }
 
